if __name__ == "__main__":
    from setuptools import setup, find_packages

    setup(
        name='SignalSemaphore',
        version='0.0.4',
        packages=find_packages(),
        install_requires=[],
        author='Jan Lerking',
        author_email='',
        description='A simple event signaling system',
        long_description=open('README.md').read(),
        long_description_content_type='text/markdown',
        url='https://gitea.com/Lerking/semaphore',
        classifiers=[
                    'Programming Language :: Python :: 3',
                    'License :: OSI Approved :: MIT License',
                    'Operating System :: OS Independent',
                    ],
        python_requires='>=3.12',
    )